pub struct AssociateFeedFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to AssociateFeed.
Associates a resource with the feed. The resource provides the input that Elemental Inference needs needs in order to perform an Elemental Inference feature, such as cropping video. You always provide the resource by associating it with a feed. You can associate only one resource with each feed.
Implementations
Sourceimpl AssociateFeedFluentBuilder
impl AssociateFeedFluentBuilder
Sourcepub fn as_input(&self) -> &AssociateFeedInputBuilder
pub fn as_input(&self) -> &AssociateFeedInputBuilder
Access the AssociateFeed as a reference.
Sourcepub async fn send(
self,
) -> Result<AssociateFeedOutput, SdkError<AssociateFeedError, HttpResponse>>
pub async fn send( self, ) -> Result<AssociateFeedOutput, SdkError<AssociateFeedError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<AssociateFeedOutput, AssociateFeedError, Self>
pub fn customize( self, ) -> CustomizableOperation<AssociateFeedOutput, AssociateFeedError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn associated_resource_name(self, input: impl Into<String>) -> Self
pub fn associated_resource_name(self, input: impl Into<String>) -> Self
An identifier for the resource. If the resource is from an AWS service, this identifier must be the full ARN of that resource. Otherwise, the identifier is a name that you assign and that is appropriate for the application that owns the resource. This name must not resemble an ARN.
Sourcepub fn set_associated_resource_name(self, input: Option<String>) -> Self
pub fn set_associated_resource_name(self, input: Option<String>) -> Self
An identifier for the resource. If the resource is from an AWS service, this identifier must be the full ARN of that resource. Otherwise, the identifier is a name that you assign and that is appropriate for the application that owns the resource. This name must not resemble an ARN.
Sourcepub fn get_associated_resource_name(&self) -> &Option<String>
pub fn get_associated_resource_name(&self) -> &Option<String>
An identifier for the resource. If the resource is from an AWS service, this identifier must be the full ARN of that resource. Otherwise, the identifier is a name that you assign and that is appropriate for the application that owns the resource. This name must not resemble an ARN.
Sourcepub fn outputs(self, input: CreateOutput) -> Self
pub fn outputs(self, input: CreateOutput) -> Self
Appends an item to outputs.
To override the contents of this collection use set_outputs.
The outputs to add to this feed. You must specify at least one output. You can later use the UpdateFeed action to change the list of outputs.
Sourcepub fn set_outputs(self, input: Option<Vec<CreateOutput>>) -> Self
pub fn set_outputs(self, input: Option<Vec<CreateOutput>>) -> Self
The outputs to add to this feed. You must specify at least one output. You can later use the UpdateFeed action to change the list of outputs.
Sourcepub fn get_outputs(&self) -> &Option<Vec<CreateOutput>>
pub fn get_outputs(&self) -> &Option<Vec<CreateOutput>>
The outputs to add to this feed. You must specify at least one output. You can later use the UpdateFeed action to change the list of outputs.
Sourcepub fn dry_run(self, input: bool) -> Self
pub fn dry_run(self, input: bool) -> Self
Set to true if you want to do a dry run of the associate action.
Sourcepub fn set_dry_run(self, input: Option<bool>) -> Self
pub fn set_dry_run(self, input: Option<bool>) -> Self
Set to true if you want to do a dry run of the associate action.
Sourcepub fn get_dry_run(&self) -> &Option<bool>
pub fn get_dry_run(&self) -> &Option<bool>
Set to true if you want to do a dry run of the associate action.