#[non_exhaustive]pub struct AssociateFeedInputBuilder { /* private fields */ }Expand description
A builder for AssociateFeedInput.
Implementations
Sourceimpl AssociateFeedInputBuilder
impl AssociateFeedInputBuilder
Sourcepub fn associated_resource_name(self, input: impl Into<String>) -> Self
pub fn associated_resource_name(self, input: impl Into<String>) -> Self
An identifier for the resource. This name must not resemble an ARN.
The resource is the source media that the feed will process. The name you assign should help you to later identify the source media that belongs to the feed. In this way, you will know which source media to push to the feed (using PutMedia).
This field is required.Sourcepub fn set_associated_resource_name(self, input: Option<String>) -> Self
pub fn set_associated_resource_name(self, input: Option<String>) -> Self
An identifier for the resource. This name must not resemble an ARN.
The resource is the source media that the feed will process. The name you assign should help you to later identify the source media that belongs to the feed. In this way, you will know which source media to push to the feed (using PutMedia).
Sourcepub fn get_associated_resource_name(&self) -> &Option<String>
pub fn get_associated_resource_name(&self) -> &Option<String>
An identifier for the resource. This name must not resemble an ARN.
The resource is the source media that the feed will process. The name you assign should help you to later identify the source media that belongs to the feed. In this way, you will know which source media to push to the feed (using PutMedia).
Sourcepub fn outputs(self, input: CreateOutput) -> Self
pub fn outputs(self, input: CreateOutput) -> Self
Appends an item to outputs.
To override the contents of this collection use set_outputs.
An array of one or more outputs that you want to add to this feed now, to supplement any outputs that you specified when you created or updated the feed.
Sourcepub fn set_outputs(self, input: Option<Vec<CreateOutput>>) -> Self
pub fn set_outputs(self, input: Option<Vec<CreateOutput>>) -> Self
An array of one or more outputs that you want to add to this feed now, to supplement any outputs that you specified when you created or updated the feed.
Sourcepub fn get_outputs(&self) -> &Option<Vec<CreateOutput>>
pub fn get_outputs(&self) -> &Option<Vec<CreateOutput>>
An array of one or more outputs that you want to add to this feed now, to supplement any outputs that you specified when you created or updated the feed.
Sourcepub fn dry_run(self, input: bool) -> Self
pub fn dry_run(self, input: bool) -> Self
Set to true if you want to do a dry run of the associate action.
Elemental Inference will validate that the real request would succeed without actually making any changes. A dry run catches errors such as missing IAM permissions, quota limits exceeded, conflicting outputs, and so on. If the dry run fails, the action returns a 4xx error code. After you've fixed the errors, resubmit the request.
Sourcepub fn set_dry_run(self, input: Option<bool>) -> Self
pub fn set_dry_run(self, input: Option<bool>) -> Self
Set to true if you want to do a dry run of the associate action.
Elemental Inference will validate that the real request would succeed without actually making any changes. A dry run catches errors such as missing IAM permissions, quota limits exceeded, conflicting outputs, and so on. If the dry run fails, the action returns a 4xx error code. After you've fixed the errors, resubmit the request.
Sourcepub fn get_dry_run(&self) -> &Option<bool>
pub fn get_dry_run(&self) -> &Option<bool>
Set to true if you want to do a dry run of the associate action.
Elemental Inference will validate that the real request would succeed without actually making any changes. A dry run catches errors such as missing IAM permissions, quota limits exceeded, conflicting outputs, and so on. If the dry run fails, the action returns a 4xx error code. After you've fixed the errors, resubmit the request.
Sourcepub fn build(self) -> Result<AssociateFeedInput, BuildError>
pub fn build(self) -> Result<AssociateFeedInput, BuildError>
Consumes the builder and constructs a AssociateFeedInput.
Sourceimpl AssociateFeedInputBuilder
impl AssociateFeedInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<AssociateFeedOutput, SdkError<AssociateFeedError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<AssociateFeedOutput, SdkError<AssociateFeedError, HttpResponse>>
Sends a request with this input using the given client.