#[non_exhaustive]pub struct AssociateFeedOutputBuilder { /* private fields */ }Expand description
A builder for AssociateFeedOutput.
Implementations
Sourceimpl AssociateFeedOutputBuilder
impl AssociateFeedOutputBuilder
Sourcepub fn arn(self, input: impl Into<String>) -> Self
pub fn arn(self, input: impl Into<String>) -> Self
The AWS ARN for this association.
This field is required.Sourcepub fn id(self, input: impl Into<String>) -> Self
pub fn id(self, input: impl Into<String>) -> Self
An ID for this response. It is unique in Elemental Inference for this AWS account.
This field is required.Sourcepub fn set_id(self, input: Option<String>) -> Self
pub fn set_id(self, input: Option<String>) -> Self
An ID for this response. It is unique in Elemental Inference for this AWS account.
Sourcepub fn get_id(&self) -> &Option<String>
pub fn get_id(&self) -> &Option<String>
An ID for this response. It is unique in Elemental Inference for this AWS account.
Sourcepub fn build(self) -> Result<AssociateFeedOutput, BuildError>
pub fn build(self) -> Result<AssociateFeedOutput, BuildError>
Consumes the builder and constructs a AssociateFeedOutput.
This method will fail if any of the following fields are not set: