AssociateFeedInput

Struct AssociateFeedInput 

#[non_exhaustive]
pub struct AssociateFeedInput { pub id: Option<String>, pub associated_resource_name: Option<String>, pub outputs: Option<Vec<CreateOutput>>, pub dry_run: Option<bool>, }

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
id: Option<String>

The ID of the feed.

associated_resource_name: Option<String>

An identifier for the resource. If the resource is from an AWS service, this identifier must be the full ARN of that resource. Otherwise, the identifier is a name that you assign and that is appropriate for the application that owns the resource. This name must not resemble an ARN.

outputs: Option<Vec<CreateOutput>>

The outputs to add to this feed. You must specify at least one output. You can later use the UpdateFeed action to change the list of outputs.

dry_run: Option<bool>

Set to true if you want to do a dry run of the associate action.

Implementations

Source

impl AssociateFeedInput

pub fn id(&self) -> Option<&str>

The ID of the feed.

pub fn associated_resource_name(&self) -> Option<&str>

An identifier for the resource. If the resource is from an AWS service, this identifier must be the full ARN of that resource. Otherwise, the identifier is a name that you assign and that is appropriate for the application that owns the resource. This name must not resemble an ARN.

pub fn outputs(&self) -> &[CreateOutput]

The outputs to add to this feed. You must specify at least one output. You can later use the UpdateFeed action to change the list of outputs.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .outputs.is_none().

pub fn dry_run(&self) -> Option<bool>

Set to true if you want to do a dry run of the associate action.

Source

impl AssociateFeedInput

pub fn builder() -> AssociateFeedInputBuilder

Creates a new builder-style object to manufacture AssociateFeedInput.