#[non_exhaustive]pub struct CreateDictionaryInputBuilder { /* private fields */ }Expand description
A builder for CreateDictionaryInput.
Implementations
Sourceimpl CreateDictionaryInputBuilder
impl CreateDictionaryInputBuilder
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
A user-friendly name for this dictionary.
This field is required.Sourcepub fn language(self, input: DictionaryLanguage) -> Self
pub fn language(self, input: DictionaryLanguage) -> Self
The language of the dictionary entries. Specify the language using an ISO 639-2/T three-letter code. Supported values: eng, fra, ita, deu, spa, por.
This field is required.Sourcepub fn set_language(self, input: Option<DictionaryLanguage>) -> Self
pub fn set_language(self, input: Option<DictionaryLanguage>) -> Self
The language of the dictionary entries. Specify the language using an ISO 639-2/T three-letter code. Supported values: eng, fra, ita, deu, spa, por.
Sourcepub fn get_language(&self) -> &Option<DictionaryLanguage>
pub fn get_language(&self) -> &Option<DictionaryLanguage>
The language of the dictionary entries. Specify the language using an ISO 639-2/T three-letter code. Supported values: eng, fra, ita, deu, spa, por.
Sourcepub fn entries(self, input: impl Into<String>) -> Self
pub fn entries(self, input: impl Into<String>) -> Self
The dictionary entries payload. Contains the custom words and phrases for the dictionary. Maximum size is 40,960 characters.
Sourcepub fn set_entries(self, input: Option<String>) -> Self
pub fn set_entries(self, input: Option<String>) -> Self
The dictionary entries payload. Contains the custom words and phrases for the dictionary. Maximum size is 40,960 characters.
Sourcepub fn get_entries(&self) -> &Option<String>
pub fn get_entries(&self) -> &Option<String>
The dictionary entries payload. Contains the custom words and phrases for the dictionary. Maximum size is 40,960 characters.
Adds a key-value pair to tags.
To override the contents of this collection use set_tags.
Optional tags to associate with the dictionary.
Optional tags to associate with the dictionary.
Optional tags to associate with the dictionary.
Sourcepub fn build(self) -> Result<CreateDictionaryInput, BuildError>
pub fn build(self) -> Result<CreateDictionaryInput, BuildError>
Consumes the builder and constructs a CreateDictionaryInput.
Sourceimpl CreateDictionaryInputBuilder
impl CreateDictionaryInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<CreateDictionaryOutput, SdkError<CreateDictionaryError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<CreateDictionaryOutput, SdkError<CreateDictionaryError, HttpResponse>>
Sends a request with this input using the given client.