#[non_exhaustive]pub struct CreateDictionaryOutputBuilder { /* private fields */ }Expand description
A builder for CreateDictionaryOutput.
Implementations
Sourceimpl CreateDictionaryOutputBuilder
impl CreateDictionaryOutputBuilder
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name that you specified in the request.
This field is required.Sourcepub fn set_name(self, input: Option<String>) -> Self
pub fn set_name(self, input: Option<String>) -> Self
The name that you specified in the request.
Sourcepub fn arn(self, input: impl Into<String>) -> Self
pub fn arn(self, input: impl Into<String>) -> Self
The ARN of the dictionary.
This field is required.Sourcepub fn id(self, input: impl Into<String>) -> Self
pub fn id(self, input: impl Into<String>) -> Self
A unique ID that Elemental Inference assigns to the dictionary.
This field is required.Sourcepub fn set_id(self, input: Option<String>) -> Self
pub fn set_id(self, input: Option<String>) -> Self
A unique ID that Elemental Inference assigns to the dictionary.
Sourcepub fn get_id(&self) -> &Option<String>
pub fn get_id(&self) -> &Option<String>
A unique ID that Elemental Inference assigns to the dictionary.
Sourcepub fn language(self, input: DictionaryLanguage) -> Self
pub fn language(self, input: DictionaryLanguage) -> Self
The language of the dictionary.
This field is required.Sourcepub fn set_language(self, input: Option<DictionaryLanguage>) -> Self
pub fn set_language(self, input: Option<DictionaryLanguage>) -> Self
The language of the dictionary.
Sourcepub fn get_language(&self) -> &Option<DictionaryLanguage>
pub fn get_language(&self) -> &Option<DictionaryLanguage>
The language of the dictionary.
Sourcepub fn status(self, input: DictionaryStatus) -> Self
pub fn status(self, input: DictionaryStatus) -> Self
The current status of the dictionary. After creation succeeds, the status will be AVAILABLE.
This field is required.Sourcepub fn set_status(self, input: Option<DictionaryStatus>) -> Self
pub fn set_status(self, input: Option<DictionaryStatus>) -> Self
The current status of the dictionary. After creation succeeds, the status will be AVAILABLE.
Sourcepub fn get_status(&self) -> &Option<DictionaryStatus>
pub fn get_status(&self) -> &Option<DictionaryStatus>
The current status of the dictionary. After creation succeeds, the status will be AVAILABLE.
Sourcepub fn references(self, input: impl Into<String>) -> Self
pub fn references(self, input: impl Into<String>) -> Self
Appends an item to references.
To override the contents of this collection use set_references.
A list of feed IDs that reference this dictionary.
Sourcepub fn set_references(self, input: Option<Vec<String>>) -> Self
pub fn set_references(self, input: Option<Vec<String>>) -> Self
A list of feed IDs that reference this dictionary.
Sourcepub fn get_references(&self) -> &Option<Vec<String>>
pub fn get_references(&self) -> &Option<Vec<String>>
A list of feed IDs that reference this dictionary.
Adds a key-value pair to tags.
To override the contents of this collection use set_tags.
Any tags that you included when you created the dictionary.
Any tags that you included when you created the dictionary.
Any tags that you included when you created the dictionary.
Sourcepub fn build(self) -> Result<CreateDictionaryOutput, BuildError>
pub fn build(self) -> Result<CreateDictionaryOutput, BuildError>