#[non_exhaustive]pub struct CreateDictionaryInput {
pub name: Option<String>,
pub language: Option<DictionaryLanguage>,
pub entries: Option<String>,
pub tags: Option<HashMap<String, String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: Option<String>A user-friendly name for this dictionary.
language: Option<DictionaryLanguage>The language of the dictionary entries. Specify the language using an ISO 639-2/T three-letter code. Supported values: eng, fra, ita, deu, spa, por.
entries: Option<String>The dictionary entries payload. Contains the custom words and phrases for the dictionary. Maximum size is 40,960 characters.
Optional tags to associate with the dictionary.
Implementations
Sourceimpl CreateDictionaryInput
impl CreateDictionaryInput
Sourcepub fn language(&self) -> Option<&DictionaryLanguage>
pub fn language(&self) -> Option<&DictionaryLanguage>
The language of the dictionary entries. Specify the language using an ISO 639-2/T three-letter code. Supported values: eng, fra, ita, deu, spa, por.
Sourcepub fn entries(&self) -> Option<&str>
pub fn entries(&self) -> Option<&str>
The dictionary entries payload. Contains the custom words and phrases for the dictionary. Maximum size is 40,960 characters.
Optional tags to associate with the dictionary.
Sourceimpl CreateDictionaryInput
impl CreateDictionaryInput
Sourcepub fn builder() -> CreateDictionaryInputBuilder
pub fn builder() -> CreateDictionaryInputBuilder
Creates a new builder-style object to manufacture CreateDictionaryInput.