#[non_exhaustive]pub struct CreateDictionaryOutput {
pub name: String,
pub arn: String,
pub id: String,
pub language: DictionaryLanguage,
pub status: DictionaryStatus,
pub references: Option<Vec<String>>,
pub tags: Option<HashMap<String, String>>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe name that you specified in the request.
arn: StringThe ARN of the dictionary.
id: StringA unique ID that Elemental Inference assigns to the dictionary.
language: DictionaryLanguageThe language of the dictionary.
status: DictionaryStatusThe current status of the dictionary. After creation succeeds, the status will be AVAILABLE.
references: Option<Vec<String>>A list of feed IDs that reference this dictionary.
Any tags that you included when you created the dictionary.
Implementations
Sourceimpl CreateDictionaryOutput
impl CreateDictionaryOutput
Sourcepub fn language(&self) -> &DictionaryLanguage
pub fn language(&self) -> &DictionaryLanguage
The language of the dictionary.
Sourcepub fn status(&self) -> &DictionaryStatus
pub fn status(&self) -> &DictionaryStatus
The current status of the dictionary. After creation succeeds, the status will be AVAILABLE.
Sourcepub fn references(&self) -> &[String]
pub fn references(&self) -> &[String]
A list of feed IDs that reference this dictionary.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .references.is_none().
Any tags that you included when you created the dictionary.
Sourceimpl CreateDictionaryOutput
impl CreateDictionaryOutput
Sourcepub fn builder() -> CreateDictionaryOutputBuilder
pub fn builder() -> CreateDictionaryOutputBuilder
Creates a new builder-style object to manufacture CreateDictionaryOutput.