CreateFeedFluentBuilder

Struct CreateFeedFluentBuilder 

pub struct CreateFeedFluentBuilder { /* private fields */ }
Fluent builder constructing a request to CreateFeed.

Creates a feed. The feed is the target for live streams being sent by the calling application. An example of a calling application is AWS Elemental MediaLive. After you create the feed, you can associate a resource with the feed.

Implementations

Source

impl CreateFeedFluentBuilder

pub fn as_input(&self) -> &CreateFeedInputBuilder

Access the CreateFeed as a reference.

pub async fn send( self, ) -> Result<CreateFeedOutput, SdkError<CreateFeedError, HttpResponse>>

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

pub fn customize( self, ) -> CustomizableOperation<CreateFeedOutput, CreateFeedError, Self>

Consumes this builder, creating a customizable operation that can be modified before being sent.

pub fn name(self, input: impl Into<String>) -> Self

A name for this feed.

pub fn set_name(self, input: Option<String>) -> Self

A name for this feed.

pub fn get_name(&self) -> &Option<String>

A name for this feed.

pub fn outputs(self, input: CreateOutput) -> Self

Appends an item to outputs.

To override the contents of this collection use set_outputs.

An array of outputs for this feed. Each output represents a specific Elemental Inference feature. For example, an output might represent the crop feature.

pub fn set_outputs(self, input: Option<Vec<CreateOutput>>) -> Self

An array of outputs for this feed. Each output represents a specific Elemental Inference feature. For example, an output might represent the crop feature.

pub fn get_outputs(&self) -> &Option<Vec<CreateOutput>>

An array of outputs for this feed. Each output represents a specific Elemental Inference feature. For example, an output might represent the crop feature.

pub fn tags(self, k: impl Into<String>, v: impl Into<String>) -> Self

Adds a key-value pair to tags.

To override the contents of this collection use set_tags.

If you want to include tags, add them now. You won't be able to add them later.

pub fn set_tags(self, input: Option<HashMap<String, String>>) -> Self

If you want to include tags, add them now. You won't be able to add them later.

pub fn get_tags(&self) -> &Option<HashMap<String, String>>

If you want to include tags, add them now. You won't be able to add them later.