#[non_exhaustive]pub struct CreateFeedInputBuilder { /* private fields */ }Expand description
A builder for CreateFeedInput.
Implementations
Sourceimpl CreateFeedInputBuilder
impl CreateFeedInputBuilder
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
A name for this feed.
This field is required.Sourcepub fn outputs(self, input: CreateOutput) -> Self
pub fn outputs(self, input: CreateOutput) -> Self
Appends an item to outputs.
To override the contents of this collection use set_outputs.
An array of outputs for this feed. Each output represents a specific Elemental Inference feature. For example, an output might represent the crop feature.
Sourcepub fn set_outputs(self, input: Option<Vec<CreateOutput>>) -> Self
pub fn set_outputs(self, input: Option<Vec<CreateOutput>>) -> Self
An array of outputs for this feed. Each output represents a specific Elemental Inference feature. For example, an output might represent the crop feature.
Sourcepub fn get_outputs(&self) -> &Option<Vec<CreateOutput>>
pub fn get_outputs(&self) -> &Option<Vec<CreateOutput>>
An array of outputs for this feed. Each output represents a specific Elemental Inference feature. For example, an output might represent the crop feature.
Adds a key-value pair to tags.
To override the contents of this collection use set_tags.
If you want to include tags, add them now. You won't be able to add them later.
If you want to include tags, add them now. You won't be able to add them later.
If you want to include tags, add them now. You won't be able to add them later.
Sourcepub fn build(self) -> Result<CreateFeedInput, BuildError>
pub fn build(self) -> Result<CreateFeedInput, BuildError>
Consumes the builder and constructs a CreateFeedInput.
Sourceimpl CreateFeedInputBuilder
impl CreateFeedInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<CreateFeedOutput, SdkError<CreateFeedError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<CreateFeedOutput, SdkError<CreateFeedError, HttpResponse>>
Sends a request with this input using the given client.