#[non_exhaustive]pub struct CreateFeedOutputBuilder { /* private fields */ }Expand description
A builder for CreateFeedOutput.
Implementations
Sourceimpl CreateFeedOutputBuilder
impl CreateFeedOutputBuilder
Sourcepub fn arn(self, input: impl Into<String>) -> Self
pub fn arn(self, input: impl Into<String>) -> Self
A unique ARN that Elemental Inference assigns to the feed.
This field is required.Sourcepub fn set_arn(self, input: Option<String>) -> Self
pub fn set_arn(self, input: Option<String>) -> Self
A unique ARN that Elemental Inference assigns to the feed.
Sourcepub fn get_arn(&self) -> &Option<String>
pub fn get_arn(&self) -> &Option<String>
A unique ARN that Elemental Inference assigns to the feed.
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name that you specified.
This field is required.Sourcepub fn id(self, input: impl Into<String>) -> Self
pub fn id(self, input: impl Into<String>) -> Self
A unique ID that Elemental Inference assigns to the feed.
This field is required.Sourcepub fn set_id(self, input: Option<String>) -> Self
pub fn set_id(self, input: Option<String>) -> Self
A unique ID that Elemental Inference assigns to the feed.
Sourcepub fn get_id(&self) -> &Option<String>
pub fn get_id(&self) -> &Option<String>
A unique ID that Elemental Inference assigns to the feed.
Sourcepub fn data_endpoints(self, input: impl Into<String>) -> Self
pub fn data_endpoints(self, input: impl Into<String>) -> Self
Appends an item to data_endpoints.
To override the contents of this collection use set_data_endpoints.
A unique ARN that Elemental Inference assigns to the feed.
Sourcepub fn set_data_endpoints(self, input: Option<Vec<String>>) -> Self
pub fn set_data_endpoints(self, input: Option<Vec<String>>) -> Self
A unique ARN that Elemental Inference assigns to the feed.
Sourcepub fn get_data_endpoints(&self) -> &Option<Vec<String>>
pub fn get_data_endpoints(&self) -> &Option<Vec<String>>
A unique ARN that Elemental Inference assigns to the feed.
Sourcepub fn outputs(self, input: GetOutput) -> Self
pub fn outputs(self, input: GetOutput) -> Self
Appends an item to outputs.
To override the contents of this collection use set_outputs.
Data endpoints that Elemental Inference assigns to the feed.
Sourcepub fn set_outputs(self, input: Option<Vec<GetOutput>>) -> Self
pub fn set_outputs(self, input: Option<Vec<GetOutput>>) -> Self
Data endpoints that Elemental Inference assigns to the feed.
Sourcepub fn get_outputs(&self) -> &Option<Vec<GetOutput>>
pub fn get_outputs(&self) -> &Option<Vec<GetOutput>>
Data endpoints that Elemental Inference assigns to the feed.
Sourcepub fn status(self, input: FeedStatus) -> Self
pub fn status(self, input: FeedStatus) -> Self
The current status of the feed. After creation of the feed has succeeded, the status will be AVAILABLE.
This field is required.Sourcepub fn set_status(self, input: Option<FeedStatus>) -> Self
pub fn set_status(self, input: Option<FeedStatus>) -> Self
The current status of the feed. After creation of the feed has succeeded, the status will be AVAILABLE.
Sourcepub fn get_status(&self) -> &Option<FeedStatus>
pub fn get_status(&self) -> &Option<FeedStatus>
The current status of the feed. After creation of the feed has succeeded, the status will be AVAILABLE.
Sourcepub fn association(self, input: FeedAssociation) -> Self
pub fn association(self, input: FeedAssociation) -> Self
The association for this feed. When you create the feed, this property is empty. You must associate a resource with the feed using AssociateFeed.
Sourcepub fn set_association(self, input: Option<FeedAssociation>) -> Self
pub fn set_association(self, input: Option<FeedAssociation>) -> Self
The association for this feed. When you create the feed, this property is empty. You must associate a resource with the feed using AssociateFeed.
Sourcepub fn get_association(&self) -> &Option<FeedAssociation>
pub fn get_association(&self) -> &Option<FeedAssociation>
The association for this feed. When you create the feed, this property is empty. You must associate a resource with the feed using AssociateFeed.
Adds a key-value pair to tags.
To override the contents of this collection use set_tags.
Any tags that you included when you created the feed.
Any tags that you included when you created the feed.
Any tags that you included when you created the feed.
Sourcepub fn build(self) -> Result<CreateFeedOutput, BuildError>
pub fn build(self) -> Result<CreateFeedOutput, BuildError>
Consumes the builder and constructs a CreateFeedOutput.
This method will fail if any of the following fields are not set: