#[non_exhaustive]pub struct CreateFeedOutput {
pub arn: String,
pub name: String,
pub id: String,
pub data_endpoints: Vec<String>,
pub outputs: Vec<GetOutput>,
pub status: FeedStatus,
pub association: Option<FeedAssociation>,
pub tags: Option<HashMap<String, String>>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.arn: StringA unique ARN that Elemental Inference assigns to the feed.
name: StringThe name that you specified.
id: StringA unique ID that Elemental Inference assigns to the feed.
data_endpoints: Vec<String>A unique ARN that Elemental Inference assigns to the feed.
outputs: Vec<GetOutput>Data endpoints that Elemental Inference assigns to the feed.
status: FeedStatusThe current status of the feed. After creation of the feed has succeeded, the status will be AVAILABLE.
association: Option<FeedAssociation>The association for this feed. When you create the feed, this property is empty. You must associate a resource with the feed using AssociateFeed.
Any tags that you included when you created the feed.
Implementations
Sourceimpl CreateFeedOutput
impl CreateFeedOutput
Sourcepub fn data_endpoints(&self) -> &[String]
pub fn data_endpoints(&self) -> &[String]
A unique ARN that Elemental Inference assigns to the feed.
Sourcepub fn outputs(&self) -> &[GetOutput]
pub fn outputs(&self) -> &[GetOutput]
Data endpoints that Elemental Inference assigns to the feed.
Sourcepub fn status(&self) -> &FeedStatus
pub fn status(&self) -> &FeedStatus
The current status of the feed. After creation of the feed has succeeded, the status will be AVAILABLE.
Sourcepub fn association(&self) -> Option<&FeedAssociation>
pub fn association(&self) -> Option<&FeedAssociation>
The association for this feed. When you create the feed, this property is empty. You must associate a resource with the feed using AssociateFeed.
Any tags that you included when you created the feed.
Sourceimpl CreateFeedOutput
impl CreateFeedOutput
Sourcepub fn builder() -> CreateFeedOutputBuilder
pub fn builder() -> CreateFeedOutputBuilder
Creates a new builder-style object to manufacture CreateFeedOutput.