pub struct DeleteDictionaryFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to DeleteDictionary.
Deletes the specified dictionary. You cannot delete a dictionary that is referenced by a feed. You must first remove the dictionary reference from the feed's subtitling configuration.
Implementations
Sourceimpl DeleteDictionaryFluentBuilder
impl DeleteDictionaryFluentBuilder
Sourcepub fn as_input(&self) -> &DeleteDictionaryInputBuilder
pub fn as_input(&self) -> &DeleteDictionaryInputBuilder
Access the DeleteDictionary as a reference.
Sourcepub async fn send(
self,
) -> Result<DeleteDictionaryOutput, SdkError<DeleteDictionaryError, HttpResponse>>
pub async fn send( self, ) -> Result<DeleteDictionaryOutput, SdkError<DeleteDictionaryError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<DeleteDictionaryOutput, DeleteDictionaryError, Self>
pub fn customize( self, ) -> CustomizableOperation<DeleteDictionaryOutput, DeleteDictionaryError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.