#[non_exhaustive]pub struct DisassociateFeedInputBuilder { /* private fields */ }Expand description
A builder for DisassociateFeedInput.
Implementations
Sourceimpl DisassociateFeedInputBuilder
impl DisassociateFeedInputBuilder
Sourcepub fn id(self, input: impl Into<String>) -> Self
pub fn id(self, input: impl Into<String>) -> Self
The ID of the feed where you want to release the resource.
This field is required.Sourcepub fn set_id(self, input: Option<String>) -> Self
pub fn set_id(self, input: Option<String>) -> Self
The ID of the feed where you want to release the resource.
Sourcepub fn get_id(&self) -> &Option<String>
pub fn get_id(&self) -> &Option<String>
The ID of the feed where you want to release the resource.
Sourcepub fn associated_resource_name(self, input: impl Into<String>) -> Self
pub fn associated_resource_name(self, input: impl Into<String>) -> Self
The name of the resource currently associated with the feed'.
This field is required.Sourcepub fn set_associated_resource_name(self, input: Option<String>) -> Self
pub fn set_associated_resource_name(self, input: Option<String>) -> Self
The name of the resource currently associated with the feed'.
Sourcepub fn get_associated_resource_name(&self) -> &Option<String>
pub fn get_associated_resource_name(&self) -> &Option<String>
The name of the resource currently associated with the feed'.
Sourcepub fn dry_run(self, input: bool) -> Self
pub fn dry_run(self, input: bool) -> Self
Set to true if you want to do a dry run of the disassociate action.
Sourcepub fn set_dry_run(self, input: Option<bool>) -> Self
pub fn set_dry_run(self, input: Option<bool>) -> Self
Set to true if you want to do a dry run of the disassociate action.
Sourcepub fn get_dry_run(&self) -> &Option<bool>
pub fn get_dry_run(&self) -> &Option<bool>
Set to true if you want to do a dry run of the disassociate action.
Sourcepub fn build(self) -> Result<DisassociateFeedInput, BuildError>
pub fn build(self) -> Result<DisassociateFeedInput, BuildError>
Consumes the builder and constructs a DisassociateFeedInput.
Sourceimpl DisassociateFeedInputBuilder
impl DisassociateFeedInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<DisassociateFeedOutput, SdkError<DisassociateFeedError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<DisassociateFeedOutput, SdkError<DisassociateFeedError, HttpResponse>>
Sends a request with this input using the given client.