#[non_exhaustive]pub struct GetDictionaryOutput {
pub name: String,
pub arn: String,
pub id: String,
pub language: DictionaryLanguage,
pub status: DictionaryStatus,
pub references: Option<Vec<String>>,
pub tags: Option<HashMap<String, String>>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe name of the dictionary.
arn: StringThe ARN of the dictionary.
id: StringThe ID of the dictionary.
language: DictionaryLanguageThe language of the dictionary.
status: DictionaryStatusThe current status of the dictionary.
references: Option<Vec<String>>A list of feed IDs that reference this dictionary.
The tags associated with the dictionary.
Implementations
Sourceimpl GetDictionaryOutput
impl GetDictionaryOutput
Sourcepub fn language(&self) -> &DictionaryLanguage
pub fn language(&self) -> &DictionaryLanguage
The language of the dictionary.
Sourcepub fn status(&self) -> &DictionaryStatus
pub fn status(&self) -> &DictionaryStatus
The current status of the dictionary.
Sourcepub fn references(&self) -> &[String]
pub fn references(&self) -> &[String]
A list of feed IDs that reference this dictionary.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .references.is_none().
The tags associated with the dictionary.
Sourceimpl GetDictionaryOutput
impl GetDictionaryOutput
Sourcepub fn builder() -> GetDictionaryOutputBuilder
pub fn builder() -> GetDictionaryOutputBuilder
Creates a new builder-style object to manufacture GetDictionaryOutput.