#[non_exhaustive]pub struct GetFeedOutput {
pub arn: String,
pub name: String,
pub id: String,
pub data_endpoints: Vec<String>,
pub outputs: Vec<GetOutput>,
pub status: FeedStatus,
pub association: Option<FeedAssociation>,
pub tags: Option<HashMap<String, String>>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.arn: StringThe ARN of the feed.
name: StringThe name of the feed being queried.
id: StringThe ID of the feed being queried.
data_endpoints: Vec<String>The dataEndpoints of the feed being queried.
outputs: Vec<GetOutput>An array of the outputs in the feed being queried.
status: FeedStatusThe status of the feed being queried.
association: Option<FeedAssociation>Information about the resource, if any, associated with the feed being queried.
A list of the tags, if any, for the feed being queried.
Implementations
Sourceimpl GetFeedOutput
impl GetFeedOutput
Sourcepub fn data_endpoints(&self) -> &[String]
pub fn data_endpoints(&self) -> &[String]
The dataEndpoints of the feed being queried.
Sourcepub fn status(&self) -> &FeedStatus
pub fn status(&self) -> &FeedStatus
The status of the feed being queried.
Sourcepub fn association(&self) -> Option<&FeedAssociation>
pub fn association(&self) -> Option<&FeedAssociation>
Information about the resource, if any, associated with the feed being queried.
A list of the tags, if any, for the feed being queried.
Sourceimpl GetFeedOutput
impl GetFeedOutput
Sourcepub fn builder() -> GetFeedOutputBuilder
pub fn builder() -> GetFeedOutputBuilder
Creates a new builder-style object to manufacture GetFeedOutput.