#[non_exhaustive]pub struct GetFixtureInputBuilder { /* private fields */ }Expand description
A builder for GetFixtureInput.
Implementations
Sourceimpl GetFixtureInputBuilder
impl GetFixtureInputBuilder
Sourcepub fn fixture_id(self, input: impl Into<String>) -> Self
pub fn fixture_id(self, input: impl Into<String>) -> Self
The ID of the fixture to retrieve, as returned by SearchFixtures.
This field is required.Sourcepub fn set_fixture_id(self, input: Option<String>) -> Self
pub fn set_fixture_id(self, input: Option<String>) -> Self
The ID of the fixture to retrieve, as returned by SearchFixtures.
Sourcepub fn get_fixture_id(&self) -> &Option<String>
pub fn get_fixture_id(&self) -> &Option<String>
The ID of the fixture to retrieve, as returned by SearchFixtures.
Sourcepub fn build(self) -> Result<GetFixtureInput, BuildError>
pub fn build(self) -> Result<GetFixtureInput, BuildError>
Consumes the builder and constructs a GetFixtureInput.
Sourceimpl GetFixtureInputBuilder
impl GetFixtureInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<GetFixtureOutput, SdkError<GetFixtureError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<GetFixtureOutput, SdkError<GetFixtureError, HttpResponse>>
Sends a request with this input using the given client.