#[non_exhaustive]pub enum GetFixtureError {
AccessDeniedException(AccessDeniedException),
GatewayTimedOutException(GatewayTimedOutException),
InternalServerErrorException(InternalServerErrorException),
ResourceNotFoundException(ResourceNotFoundException),
ServiceUnavailableException(ServiceUnavailableException),
TooManyRequestException(TooManyRequestException),
ValidationException(ValidationException),
Unhandled(Unhandled),
}Expand description
Error type for the GetFixtureError operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AccessDeniedException(AccessDeniedException)
You do not have sufficient access to perform this action.
GatewayTimedOutException(GatewayTimedOutException)
The request timed out before the service returned a response. This is a temporary condition. Retry the request. If the problem persists, contact AWS Support.
InternalServerErrorException(InternalServerErrorException)
An internal server error occurred. This is a temporary condition and the request can be retried. If the problem persists, contact AWS Support.
ResourceNotFoundException(ResourceNotFoundException)
The resource specified in the action doesn't exist.
The service is temporarily unable to handle the request. Retry the request. If the problem persists, contact AWS Support.
TooManyRequestException(TooManyRequestException)
The request was denied due to request throttling. Too many requests have been made within a given time period. Reduce the frequency of requests and use exponential backoff when retrying.
ValidationException(ValidationException)
The input fails to satisfy the constraints specified by the service. Check the error message for details about which parameter or field is invalid and correct the request before retrying.
Unhandled(Unhandled)
Matching Unhandled directly is not forwards compatible. Instead, match using a variable wildcard pattern and check .code():
err if err.code() == Some("SpecificExceptionCode") => { /* handle the error */ }
See ProvideErrorMetadata for what information is available for the error.
An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).
Implementations
Sourceimpl GetFixtureError
impl GetFixtureError
Sourcepub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
pub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
Creates the GetFixtureError::Unhandled variant from any error type.
Sourcepub fn generic(err: ErrorMetadata) -> Self
pub fn generic(err: ErrorMetadata) -> Self
Creates the GetFixtureError::Unhandled variant from an ErrorMetadata.
Sourcepub fn meta(&self) -> &ErrorMetadata
pub fn meta(&self) -> &ErrorMetadata
Returns error metadata, which includes the error code, message, request ID, and potentially additional information.
Sourcepub fn is_access_denied_exception(&self) -> bool
pub fn is_access_denied_exception(&self) -> bool
Returns true if the error kind is GetFixtureError::AccessDeniedException.
Sourcepub fn is_gateway_timed_out_exception(&self) -> bool
pub fn is_gateway_timed_out_exception(&self) -> bool
Returns true if the error kind is GetFixtureError::GatewayTimedOutException.
Sourcepub fn is_internal_server_error_exception(&self) -> bool
pub fn is_internal_server_error_exception(&self) -> bool
Returns true if the error kind is GetFixtureError::InternalServerErrorException.
Sourcepub fn is_resource_not_found_exception(&self) -> bool
pub fn is_resource_not_found_exception(&self) -> bool
Returns true if the error kind is GetFixtureError::ResourceNotFoundException.
Returns true if the error kind is GetFixtureError::ServiceUnavailableException.
Sourcepub fn is_too_many_request_exception(&self) -> bool
pub fn is_too_many_request_exception(&self) -> bool
Returns true if the error kind is GetFixtureError::TooManyRequestException.
Sourcepub fn is_validation_exception(&self) -> bool
pub fn is_validation_exception(&self) -> bool
Returns true if the error kind is GetFixtureError::ValidationException.