#[non_exhaustive]pub struct GetFixtureInput {
pub fixture_id: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.fixture_id: Option<String>The ID of the fixture to retrieve, as returned by SearchFixtures.
Implementations
Sourceimpl GetFixtureInput
impl GetFixtureInput
Sourcepub fn fixture_id(&self) -> Option<&str>
pub fn fixture_id(&self) -> Option<&str>
The ID of the fixture to retrieve, as returned by SearchFixtures.
Sourceimpl GetFixtureInput
impl GetFixtureInput
Sourcepub fn builder() -> GetFixtureInputBuilder
pub fn builder() -> GetFixtureInputBuilder
Creates a new builder-style object to manufacture GetFixtureInput.