#[non_exhaustive]pub struct ListFeedsOutput {
pub feeds: Vec<FeedSummary>,
pub next_token: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.feeds: Vec<FeedSummary>A list of feed summaries.
next_token: Option<String>The token that identifies the batch of results that you want to see. For example, you submit a list request with MaxResults set at 5. The service returns the first batch of results (up to 5) and a NextToken value. To see the next batch of results, you can submit the list request a second time and specify the NextToken value.
Implementations
Sourceimpl ListFeedsOutput
impl ListFeedsOutput
Sourcepub fn feeds(&self) -> &[FeedSummary]
pub fn feeds(&self) -> &[FeedSummary]
A list of feed summaries.
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
The token that identifies the batch of results that you want to see. For example, you submit a list request with MaxResults set at 5. The service returns the first batch of results (up to 5) and a NextToken value. To see the next batch of results, you can submit the list request a second time and specify the NextToken value.
Sourceimpl ListFeedsOutput
impl ListFeedsOutput
Sourcepub fn builder() -> ListFeedsOutputBuilder
pub fn builder() -> ListFeedsOutputBuilder
Creates a new builder-style object to manufacture ListFeedsOutput.