#[non_exhaustive]pub struct UpdateFeedOutput {
pub arn: String,
pub name: String,
pub id: String,
pub data_endpoints: Vec<String>,
pub outputs: Vec<GetOutput>,
pub status: FeedStatus,
pub association: Option<FeedAssociation>,
pub tags: Option<HashMap<String, String>>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.arn: StringThe ARN of the feed.
name: StringThe updated or original name of the feed.
id: StringThe ID of the feed.
data_endpoints: Vec<String>The data endpoints of the feed.
outputs: Vec<GetOutput>The array of outputs in the feed. You might have left this array unchanged, or you might have changed it.
status: FeedStatusThe status of the output.
association: Option<FeedAssociation>True means that the output was originally created in the feed by the AssociateFeed operation. False means it was created using CreateFeed or UpdateFeed. You will need this value if you use the UpdateFeed operation to modify the list of outputs in the feed.
The name of the resource currently associated with the feed, if any.
Implementations
Sourceimpl UpdateFeedOutput
impl UpdateFeedOutput
Sourcepub fn data_endpoints(&self) -> &[String]
pub fn data_endpoints(&self) -> &[String]
The data endpoints of the feed.
Sourcepub fn outputs(&self) -> &[GetOutput]
pub fn outputs(&self) -> &[GetOutput]
The array of outputs in the feed. You might have left this array unchanged, or you might have changed it.
Sourcepub fn status(&self) -> &FeedStatus
pub fn status(&self) -> &FeedStatus
The status of the output.
Sourcepub fn association(&self) -> Option<&FeedAssociation>
pub fn association(&self) -> Option<&FeedAssociation>
True means that the output was originally created in the feed by the AssociateFeed operation. False means it was created using CreateFeed or UpdateFeed. You will need this value if you use the UpdateFeed operation to modify the list of outputs in the feed.
The name of the resource currently associated with the feed, if any.
Sourceimpl UpdateFeedOutput
impl UpdateFeedOutput
Sourcepub fn builder() -> UpdateFeedOutputBuilder
pub fn builder() -> UpdateFeedOutputBuilder
Creates a new builder-style object to manufacture UpdateFeedOutput.