pub struct Client { /* private fields */ }Expand description
Client for AWS Elemental Inference
Client for invoking operations on AWS Elemental Inference. Each operation on AWS Elemental Inference is a method on this
this struct. .send() MUST be invoked on the generated operations to dispatch the request to the service.
Constructing a Client
A Config is required to construct a client. For most use cases, the aws-config
crate should be used to automatically resolve this config using
aws_config::load_from_env(), since this will resolve an SdkConfig which can be shared
across multiple different AWS SDK clients. This config resolution process can be customized
by calling aws_config::from_env() instead, which returns a ConfigLoader that uses
the builder pattern to customize the default config.
In the simplest case, creating a client looks as follows:
let config = aws_config::load_from_env().await;
let client = aws_sdk_elementalinference::Client::new(&config);Occasionally, SDKs may have additional service-specific values that can be set on the Config that
is absent from SdkConfig, or slightly different settings for a specific client may be desired.
The Builder struct implements From<&SdkConfig>, so setting these specific settings can be
done as follows:
let sdk_config = ::aws_config::load_from_env().await;
let config = aws_sdk_elementalinference::config::Builder::from(&sdk_config)
.some_service_specific_setting("value")
.build();See the aws-config docs and Config for more information on customizing configuration.
Note: Client construction is expensive due to connection thread pool initialization, and should be done once at application start-up.
Using the Client
A client has a function for every operation that can be performed by the service.
For example, the AssociateFeed operation has
a Client::associate_feed, function which returns a builder for that operation.
The fluent builder ultimately has a send() function that returns an async future that
returns a result, as illustrated below:
let result = client.associate_feed()
.id("example")
.send()
.await;The underlying HTTP requests that get made by this can be modified with the customize_operation
function on the fluent builder. See the customize module for more
information.
Waiters
This client provides wait_until methods behind the Waiters trait.
To use them, simply import the trait, and then call one of the wait_until methods. This will
return a waiter fluent builder that takes various parameters, which are documented on the builder
type. Once parameters have been provided, the wait method can be called to initiate waiting.
For example, if there was a wait_until_thing method, it could look like:
let result = client.wait_until_thing()
.thing_id("someId")
.wait(Duration::from_secs(120))
.await;Implementations
Sourceimpl Client
impl Client
Sourcepub fn associate_feed(&self) -> AssociateFeedFluentBuilder
pub fn associate_feed(&self) -> AssociateFeedFluentBuilder
Constructs a fluent builder for the AssociateFeed operation.
- The fluent builder is configurable:
id(impl Into<String>)/set_id(Option<String>):
required: trueThe ID of the feed.
associated_resource_name(impl Into<String>)/set_associated_resource_name(Option<String>):
required: trueAn identifier for the resource. This name must not resemble an ARN.
The resource is the source media that the feed will process. The name you assign should help you to later identify the source media that belongs to the feed. In this way, you will know which source media to push to the feed (using PutMedia).
outputs(CreateOutput)/set_outputs(Option<Vec::<CreateOutput>>):
required: trueAn array of one or more outputs that you want to add to this feed now, to supplement any outputs that you specified when you created or updated the feed.
dry_run(bool)/set_dry_run(Option<bool>):
required: falseSet to true if you want to do a dry run of the associate action.
Elemental Inference will validate that the real request would succeed without actually making any changes. A dry run catches errors such as missing IAM permissions, quota limits exceeded, conflicting outputs, and so on. If the dry run fails, the action returns a 4xx error code. After you’ve fixed the errors, resubmit the request.
- On success, responds with
AssociateFeedOutputwith field(s):arn(String):The ARN of the feed.
id(String):The ID of the feed.
- On failure, responds with
SdkError<AssociateFeedError>
Sourceimpl Client
impl Client
Sourcepub fn create_dictionary(&self) -> CreateDictionaryFluentBuilder
pub fn create_dictionary(&self) -> CreateDictionaryFluentBuilder
Constructs a fluent builder for the CreateDictionary operation.
- The fluent builder is configurable:
name(impl Into<String>)/set_name(Option<String>):
required: trueA user-friendly name for this dictionary.
language(DictionaryLanguage)/set_language(Option<DictionaryLanguage>):
required: trueThe language of the dictionary entries. Specify the language using an ISO 639-2/T three-letter code. Supported values: eng, fra, ita, deu, spa, por.
entries(impl Into<String>)/set_entries(Option<String>):
required: falseThe dictionary entries payload. Contains the custom words and phrases for the dictionary. Maximum size is 40,960 characters.
tags(impl Into<String>, impl Into<String>)/set_tags(Option<HashMap::<String, String>>):
required: falseOptional tags to associate with the dictionary.
- On success, responds with
CreateDictionaryOutputwith field(s):name(String):The name that you specified in the request.
arn(String):The ARN of the dictionary.
id(String):A unique ID that Elemental Inference assigns to the dictionary.
language(DictionaryLanguage):The language of the dictionary.
status(DictionaryStatus):The current status of the dictionary. After creation succeeds, the status will be AVAILABLE.
references(Option<Vec::<String>>):A list of feed IDs that reference this dictionary.
tags(Option<HashMap::<String, String>>):Any tags that you included when you created the dictionary.
- On failure, responds with
SdkError<CreateDictionaryError>
Sourceimpl Client
impl Client
Sourcepub fn create_feed(&self) -> CreateFeedFluentBuilder
pub fn create_feed(&self) -> CreateFeedFluentBuilder
Constructs a fluent builder for the CreateFeed operation.
- The fluent builder is configurable:
name(impl Into<String>)/set_name(Option<String>):
required: trueA user-friendly name for this feed.
outputs(CreateOutput)/set_outputs(Option<Vec::<CreateOutput>>):
required: trueAn array of outputs for this feed. Each output represents a specific Elemental Inference feature. For example, there is one output type for the smart crop feature. You must specify at least one output, but you can later add outputs using AssociateFeed, or add, modify, and delete outputs using UpdateFeed.
tags(impl Into<String>, impl Into<String>)/set_tags(Option<HashMap::<String, String>>):
required: falseOptional tags. You can also add tags later, using TagResource.
- On success, responds with
CreateFeedOutputwith field(s):arn(String):A unique ARN that Elemental Inference assigns to the feed.
name(String):The name that you specified in the request.
id(String):A unique ID that Elemental Inference assigns to the feed.
data_endpoints(Vec::<String>):An array of endpoints for the feed. Typically, there is only one endpoint. The feed receives source media at this endpoint (when the calling application calls PutMedia) and returns the resulting metadata to this endpoint (when the calling application calls GetMetadata).
outputs(Vec::<GetOutput>):Repeats the outputs that you specified in the request.
status(FeedStatus):The current status of the feed. After creation of the feed has succeeded, the status will be AVAILABLE.
association(Option<FeedAssociation>):The association for this feed. When you create the feed, this property is empty. You must associate a resource with the feed using AssociateFeed or UpdateFeed.
tags(Option<HashMap::<String, String>>):Any tags that you included when you created the feed.
- On failure, responds with
SdkError<CreateFeedError>
Sourceimpl Client
impl Client
Sourcepub fn delete_dictionary(&self) -> DeleteDictionaryFluentBuilder
pub fn delete_dictionary(&self) -> DeleteDictionaryFluentBuilder
Constructs a fluent builder for the DeleteDictionary operation.
- The fluent builder is configurable:
id(impl Into<String>)/set_id(Option<String>):
required: trueThe ID of the dictionary to delete.
- On success, responds with
DeleteDictionaryOutputwith field(s):arn(String):The ARN of the deleted dictionary.
id(String):The ID of the deleted dictionary.
status(DictionaryStatus):The status of the dictionary after deletion.
- On failure, responds with
SdkError<DeleteDictionaryError>
Sourceimpl Client
impl Client
Sourcepub fn delete_feed(&self) -> DeleteFeedFluentBuilder
pub fn delete_feed(&self) -> DeleteFeedFluentBuilder
Constructs a fluent builder for the DeleteFeed operation.
- The fluent builder is configurable:
id(impl Into<String>)/set_id(Option<String>):
required: trueThe ID of the feed.
- On success, responds with
DeleteFeedOutputwith field(s):arn(String):The ARN of the deleted feed.
id(String):The ID of the deleted feed.
status(FeedStatus):The current status of the feed. When deletion of the feed has succeeded, the status will be DELETED.
- On failure, responds with
SdkError<DeleteFeedError>
Sourceimpl Client
impl Client
Sourcepub fn disassociate_feed(&self) -> DisassociateFeedFluentBuilder
pub fn disassociate_feed(&self) -> DisassociateFeedFluentBuilder
Constructs a fluent builder for the DisassociateFeed operation.
- The fluent builder is configurable:
id(impl Into<String>)/set_id(Option<String>):
required: trueThe ID of the feed where you want to release the resource.
associated_resource_name(impl Into<String>)/set_associated_resource_name(Option<String>):
required: trueThe name of the resource currently associated with the feed.
dry_run(bool)/set_dry_run(Option<bool>):
required: falseSet to true if you want to do a dry run of the disassociate action.
Elemental Inference will validate that the real request would succeed without actually making any changes. A dry run catches errors such as missing IAM permissions. If the dry run fails, the action returns a 4xx error code.
- On success, responds with
DisassociateFeedOutputwith field(s):arn(String):The ARN of the feed.
id(String):The ID of the feed.
- On failure, responds with
SdkError<DisassociateFeedError>
Sourceimpl Client
impl Client
Sourcepub fn export_dictionary_entries(&self) -> ExportDictionaryEntriesFluentBuilder
pub fn export_dictionary_entries(&self) -> ExportDictionaryEntriesFluentBuilder
Constructs a fluent builder for the ExportDictionaryEntries operation.
- The fluent builder is configurable:
id(impl Into<String>)/set_id(Option<String>):
required: trueThe ID of the dictionary whose entries you want to export.
- On success, responds with
ExportDictionaryEntriesOutputwith field(s):entries(Option<String>):The dictionary entries payload.
- On failure, responds with
SdkError<ExportDictionaryEntriesError>
Sourceimpl Client
impl Client
Sourcepub fn get_dictionary(&self) -> GetDictionaryFluentBuilder
pub fn get_dictionary(&self) -> GetDictionaryFluentBuilder
Constructs a fluent builder for the GetDictionary operation.
- The fluent builder is configurable:
id(impl Into<String>)/set_id(Option<String>):
required: trueThe ID of the dictionary to retrieve.
- On success, responds with
GetDictionaryOutputwith field(s):name(String):The name of the dictionary.
arn(String):The ARN of the dictionary.
id(String):The ID of the dictionary.
language(DictionaryLanguage):The language of the dictionary.
status(DictionaryStatus):The current status of the dictionary.
references(Option<Vec::<String>>):A list of feed IDs that reference this dictionary.
tags(Option<HashMap::<String, String>>):The tags associated with the dictionary.
- On failure, responds with
SdkError<GetDictionaryError>
Sourceimpl Client
impl Client
Sourcepub fn get_feed(&self) -> GetFeedFluentBuilder
pub fn get_feed(&self) -> GetFeedFluentBuilder
Constructs a fluent builder for the GetFeed operation.
- The fluent builder is configurable:
id(impl Into<String>)/set_id(Option<String>):
required: trueThe ID of the feed to query.
- On success, responds with
GetFeedOutputwith field(s):arn(String):The ARN of the feed.
name(String):The name of the feed.
id(String):The ID of the feed.
data_endpoints(Vec::<String>):The dataEndpoints of the feed.
outputs(Vec::<GetOutput>):An array of the outputs in the feed.
status(FeedStatus):The status of the feed.
association(Option<FeedAssociation>):Information about the resource that is associated with the feed. It’s possible that there is no associated resource. This is not an error.
tags(Option<HashMap::<String, String>>):A list of the tags, if any, for the feed.
- On failure, responds with
SdkError<GetFeedError>
Sourceimpl Client
impl Client
Sourcepub fn list_dictionaries(&self) -> ListDictionariesFluentBuilder
pub fn list_dictionaries(&self) -> ListDictionariesFluentBuilder
Constructs a fluent builder for the ListDictionaries operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
max_results(i32)/set_max_results(Option<i32>):
required: falseThe maximum number of results to return per API request. Valid range: 1 to 100.
next_token(impl Into<String>)/set_next_token(Option<String>):
required: falseThe token that identifies the next batch of results to return.
- On success, responds with
ListDictionariesOutputwith field(s):dictionaries(Vec::<DictionarySummary>):A list of DictionarySummary objects.
next_token(Option<String>):The token to use to retrieve the next batch of results.
- On failure, responds with
SdkError<ListDictionariesError>
Sourceimpl Client
impl Client
Sourcepub fn list_feeds(&self) -> ListFeedsFluentBuilder
pub fn list_feeds(&self) -> ListFeedsFluentBuilder
Constructs a fluent builder for the ListFeeds operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
max_results(i32)/set_max_results(Option<i32>):
required: falseThe maximum number of results to return per API request.
For example, you submit a list request with MaxResults set at 5. Although 20 items match your request, the service returns no more than the first 5 items. (The service also returns a NextToken value that you can use to fetch the next batch of results.)
The service might return fewer results than the MaxResults value. If MaxResults is not included in the request, the service defaults to pagination with a maximum of 10 results per page.
Valid Range: Minimum value of 1. Maximum value of 1000.
next_token(impl Into<String>)/set_next_token(Option<String>):
required: falseThe token that identifies the batch of results that you want to see.
For example, you submit a ListFeeds request with MaxResults set at 5. The service returns the first batch of results (up to 5) and a NextToken value. To see the next batch of results, you can submit the ListFeeds request a second time and specify the NextToken value.
- On success, responds with
ListFeedsOutputwith field(s):feeds(Vec::<FeedSummary>):A list of FeedSummary objects.
next_token(Option<String>):The token that identifies the batch of results that you want to see. For example, you submit a list request with MaxResults set at 5. The service returns the first batch of results (up to 5) and a NextToken value. To see the next batch of results, you can submit the list request a second time and specify the NextToken value.
- On failure, responds with
SdkError<ListFeedsError>
Sourceimpl Client
impl Client
Constructs a fluent builder for the ListTagsForResource operation.
- The fluent builder is configurable:
resource_arn(impl Into<String>)/set_resource_arn(Option<String>):
required: trueThe ARN of the resource whose tags you want to query.
- On success, responds with
ListTagsForResourceOutputwith field(s):tags(Option<HashMap::<String, String>>):A list of the tags that belong to this resource.
- On failure, responds with
SdkError<ListTagsForResourceError>
Sourceimpl Client
impl Client
Sourcepub fn tag_resource(&self) -> TagResourceFluentBuilder
pub fn tag_resource(&self) -> TagResourceFluentBuilder
Constructs a fluent builder for the TagResource operation.
- The fluent builder is configurable:
resource_arn(impl Into<String>)/set_resource_arn(Option<String>):
required: trueThe ARN of the resource where you want to add tags.
tags(impl Into<String>, impl Into<String>)/set_tags(Option<HashMap::<String, String>>):
required: trueA list of tags to add to the resource.
- On success, responds with
TagResourceOutput - On failure, responds with
SdkError<TagResourceError>
Sourceimpl Client
impl Client
Sourcepub fn untag_resource(&self) -> UntagResourceFluentBuilder
pub fn untag_resource(&self) -> UntagResourceFluentBuilder
Constructs a fluent builder for the UntagResource operation.
- The fluent builder is configurable:
resource_arn(impl Into<String>)/set_resource_arn(Option<String>):
required: trueThe ARN of the resource where you want to delete one or more tags.
tag_keys(impl Into<String>)/set_tag_keys(Option<Vec::<String>>):
required: trueThe keys of the tags to delete.
- On success, responds with
UntagResourceOutput - On failure, responds with
SdkError<UntagResourceError>
Sourceimpl Client
impl Client
Sourcepub fn update_dictionary(&self) -> UpdateDictionaryFluentBuilder
pub fn update_dictionary(&self) -> UpdateDictionaryFluentBuilder
Constructs a fluent builder for the UpdateDictionary operation.
- The fluent builder is configurable:
id(impl Into<String>)/set_id(Option<String>):
required: trueThe ID of the dictionary to update.
name(impl Into<String>)/set_name(Option<String>):
required: falseA new name for the dictionary. If not specified, the name is not changed.
language(DictionaryLanguage)/set_language(Option<DictionaryLanguage>):
required: falseA new language for the dictionary. If not specified, the language is not changed.
entries(impl Into<String>)/set_entries(Option<String>):
required: falseNew dictionary entries. If not specified, the entries are not changed.
- On success, responds with
UpdateDictionaryOutputwith field(s):name(String):The updated or original name of the dictionary.
arn(String):The ARN of the dictionary.
id(String):The ID of the dictionary.
language(DictionaryLanguage):The updated or original language of the dictionary.
status(DictionaryStatus):The current status of the dictionary.
references(Option<Vec::<String>>):A list of feed IDs that reference this dictionary.
tags(Option<HashMap::<String, String>>):Any tags associated with the dictionary.
- On failure, responds with
SdkError<UpdateDictionaryError>
Sourceimpl Client
impl Client
Sourcepub fn update_feed(&self) -> UpdateFeedFluentBuilder
pub fn update_feed(&self) -> UpdateFeedFluentBuilder
Constructs a fluent builder for the UpdateFeed operation.
- The fluent builder is configurable:
name(impl Into<String>)/set_name(Option<String>):
required: trueRequired. You can specify the existing name (to leave it unchanged) or a new name.
id(impl Into<String>)/set_id(Option<String>):
required: trueThe ID of the feed to update.
outputs(UpdateOutput)/set_outputs(Option<Vec::<UpdateOutput>>):
required: trueRequired. You can specify the existing array of outputs (to leave outputs unchanged) or you can specify a new array.
- On success, responds with
UpdateFeedOutputwith field(s):arn(String):The ARN of the feed.
name(String):The updated or original name of the feed.
id(String):The ID of the feed.
data_endpoints(Vec::<String>):The data endpoints of the feed.
outputs(Vec::<GetOutput>):The array of outputs in the feed. You might have left this array unchanged, or you might have changed it.
status(FeedStatus):The status of the feed.
association(Option<FeedAssociation>):Information about the resource that is associated with the feed, if any.
tags(Option<HashMap::<String, String>>):The tags associated with the feed.
- On failure, responds with
SdkError<UpdateFeedError>
Sourceimpl Client
impl Client
Sourcepub fn from_conf(conf: Config) -> Self
pub fn from_conf(conf: Config) -> Self
Creates a new client from the service Config.
Panics
This method will panic in the following cases:
- Retries or timeouts are enabled without a
sleep_implconfigured. - Identity caching is enabled without a
sleep_implandtime_sourceconfigured. - No
behavior_versionis provided.
The panic message for each of these will have instructions on how to resolve them.
Sourceimpl Client
impl Client
Sourcepub fn new(sdk_config: &SdkConfig) -> Self
pub fn new(sdk_config: &SdkConfig) -> Self
Creates a new client from an SDK Config.
Panics
- This method will panic if the
sdk_configis missing an async sleep implementation. If you experience this panic, set thesleep_implon the Config passed into this function to fix it. - This method will panic if the
sdk_configis missing an HTTP connector. If you experience this panic, set thehttp_connectoron the Config passed into this function to fix it. - This method will panic if no
BehaviorVersionis provided. If you experience this panic, setbehavior_versionon the Config or enable thebehavior-version-latestCargo feature.