#[non_exhaustive]pub struct ContextualMetadataConfigBuilder { /* private fields */ }Expand description
A builder for ContextualMetadataConfig.
Implementations
Sourceimpl ContextualMetadataConfigBuilder
impl ContextualMetadataConfigBuilder
Sourcepub fn summary_generation(self, input: SummaryGenerationMode) -> Self
pub fn summary_generation(self, input: SummaryGenerationMode) -> Self
Specifies whether Elemental Inference generates a descriptive summary of the media content for this output.
Valid values:
-
ENABLED (default) – Elemental Inference generates a descriptive summary along with IAB taxonomy and GARM suitability classifications.
-
DISABLED – No descriptive summary is generated.
Sourcepub fn set_summary_generation(
self,
input: Option<SummaryGenerationMode>,
) -> Self
pub fn set_summary_generation( self, input: Option<SummaryGenerationMode>, ) -> Self
Specifies whether Elemental Inference generates a descriptive summary of the media content for this output.
Valid values:
-
ENABLED (default) – Elemental Inference generates a descriptive summary along with IAB taxonomy and GARM suitability classifications.
-
DISABLED – No descriptive summary is generated.
Sourcepub fn get_summary_generation(&self) -> &Option<SummaryGenerationMode>
pub fn get_summary_generation(&self) -> &Option<SummaryGenerationMode>
Specifies whether Elemental Inference generates a descriptive summary of the media content for this output.
Valid values:
-
ENABLED (default) – Elemental Inference generates a descriptive summary along with IAB taxonomy and GARM suitability classifications.
-
DISABLED – No descriptive summary is generated.
Sourcepub fn build(self) -> ContextualMetadataConfig
pub fn build(self) -> ContextualMetadataConfig
Consumes the builder and constructs a ContextualMetadataConfig.