#[non_exhaustive]pub struct FixtureSummaryBuilder { /* private fields */ }Expand description
A builder for FixtureSummary.
Implementations
Sourceimpl FixtureSummaryBuilder
impl FixtureSummaryBuilder
Sourcepub fn fixture_id(self, input: impl Into<String>) -> Self
pub fn fixture_id(self, input: impl Into<String>) -> Self
The ID of the fixture. Specify this ID in the clipping output of a feed, to identify the fixture whose event data you want Elemental Inference to map onto the clipping metadata.
This field is required.Sourcepub fn set_fixture_id(self, input: Option<String>) -> Self
pub fn set_fixture_id(self, input: Option<String>) -> Self
The ID of the fixture. Specify this ID in the clipping output of a feed, to identify the fixture whose event data you want Elemental Inference to map onto the clipping metadata.
Sourcepub fn get_fixture_id(&self) -> &Option<String>
pub fn get_fixture_id(&self) -> &Option<String>
The ID of the fixture. Specify this ID in the clipping output of a feed, to identify the fixture whose event data you want Elemental Inference to map onto the clipping metadata.
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name of the fixture, as provided by the data source. For example, the names of the two competing teams.
This field is required.Sourcepub fn set_name(self, input: Option<String>) -> Self
pub fn set_name(self, input: Option<String>) -> Self
The name of the fixture, as provided by the data source. For example, the names of the two competing teams.
Sourcepub fn get_name(&self) -> &Option<String>
pub fn get_name(&self) -> &Option<String>
The name of the fixture, as provided by the data source. For example, the names of the two competing teams.
Sourcepub fn fixture_group(self, input: impl Into<String>) -> Self
pub fn fixture_group(self, input: impl Into<String>) -> Self
The group that the fixture belongs to, such as the competition, league, or tournament. The data source doesn't provide this information for every fixture.
Sourcepub fn set_fixture_group(self, input: Option<String>) -> Self
pub fn set_fixture_group(self, input: Option<String>) -> Self
The group that the fixture belongs to, such as the competition, league, or tournament. The data source doesn't provide this information for every fixture.
Sourcepub fn get_fixture_group(&self) -> &Option<String>
pub fn get_fixture_group(&self) -> &Option<String>
The group that the fixture belongs to, such as the competition, league, or tournament. The data source doesn't provide this information for every fixture.
Sourcepub fn scheduled_start(self, input: DateTime) -> Self
pub fn scheduled_start(self, input: DateTime) -> Self
The scheduled start time of the fixture, as provided by the data source. The actual start time might differ.
Sourcepub fn set_scheduled_start(self, input: Option<DateTime>) -> Self
pub fn set_scheduled_start(self, input: Option<DateTime>) -> Self
The scheduled start time of the fixture, as provided by the data source. The actual start time might differ.
Sourcepub fn get_scheduled_start(&self) -> &Option<DateTime>
pub fn get_scheduled_start(&self) -> &Option<DateTime>
The scheduled start time of the fixture, as provided by the data source. The actual start time might differ.
Sourcepub fn status(self, input: impl Into<String>) -> Self
pub fn status(self, input: impl Into<String>) -> Self
The status of the fixture in its lifecycle, as provided by the data source. For example, Scheduled or Completed.
This field is required.Sourcepub fn set_status(self, input: Option<String>) -> Self
pub fn set_status(self, input: Option<String>) -> Self
The status of the fixture in its lifecycle, as provided by the data source. For example, Scheduled or Completed.
Sourcepub fn get_status(&self) -> &Option<String>
pub fn get_status(&self) -> &Option<String>
The status of the fixture in its lifecycle, as provided by the data source. For example, Scheduled or Completed.
Sourcepub fn competitors(self, input: Competitor) -> Self
pub fn competitors(self, input: Competitor) -> Self
Appends an item to competitors.
To override the contents of this collection use set_competitors.
An array of the competitors (the teams or individuals) in the fixture.
Sourcepub fn set_competitors(self, input: Option<Vec<Competitor>>) -> Self
pub fn set_competitors(self, input: Option<Vec<Competitor>>) -> Self
An array of the competitors (the teams or individuals) in the fixture.
Sourcepub fn get_competitors(&self) -> &Option<Vec<Competitor>>
pub fn get_competitors(&self) -> &Option<Vec<Competitor>>
An array of the competitors (the teams or individuals) in the fixture.
Sourcepub fn build(self) -> Result<FixtureSummary, BuildError>
pub fn build(self) -> Result<FixtureSummary, BuildError>
Consumes the builder and constructs a FixtureSummary.
This method will fail if any of the following fields are not set: