#[non_exhaustive]pub struct GetOutputBuilder { /* private fields */ }Expand description
A builder for GetOutput.
Implementations
Sourceimpl GetOutputBuilder
impl GetOutputBuilder
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The ARN of the output.
This field is required.Sourcepub fn output_config(self, input: OutputConfig) -> Self
pub fn output_config(self, input: OutputConfig) -> Self
A typed property for an output in a feed. It is used in the GetFeed action. It identifies the action for Elemental Inference to perform. It also provides a repository for the results of that action. For example, CroppingConfig output will contain the metadata for the crop feature.
This field is required.Sourcepub fn set_output_config(self, input: Option<OutputConfig>) -> Self
pub fn set_output_config(self, input: Option<OutputConfig>) -> Self
A typed property for an output in a feed. It is used in the GetFeed action. It identifies the action for Elemental Inference to perform. It also provides a repository for the results of that action. For example, CroppingConfig output will contain the metadata for the crop feature.
Sourcepub fn get_output_config(&self) -> &Option<OutputConfig>
pub fn get_output_config(&self) -> &Option<OutputConfig>
A typed property for an output in a feed. It is used in the GetFeed action. It identifies the action for Elemental Inference to perform. It also provides a repository for the results of that action. For example, CroppingConfig output will contain the metadata for the crop feature.
Sourcepub fn status(self, input: OutputStatus) -> Self
pub fn status(self, input: OutputStatus) -> Self
The status of the output.
This field is required.Sourcepub fn set_status(self, input: Option<OutputStatus>) -> Self
pub fn set_status(self, input: Option<OutputStatus>) -> Self
The status of the output.
Sourcepub fn get_status(&self) -> &Option<OutputStatus>
pub fn get_status(&self) -> &Option<OutputStatus>
The status of the output.
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
The description of the output.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
The description of the output.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
The description of the output.
Sourcepub fn from_association(self, input: bool) -> Self
pub fn from_association(self, input: bool) -> Self
True means that the output was originally created in the feed by the AssociateFeed operation. False means it was created using CreateFeed or UpdateFeed. You will need this value if you use the UpdateFeed operation to modify the list of outputs in the feed.
Sourcepub fn set_from_association(self, input: Option<bool>) -> Self
pub fn set_from_association(self, input: Option<bool>) -> Self
True means that the output was originally created in the feed by the AssociateFeed operation. False means it was created using CreateFeed or UpdateFeed. You will need this value if you use the UpdateFeed operation to modify the list of outputs in the feed.
Sourcepub fn get_from_association(&self) -> &Option<bool>
pub fn get_from_association(&self) -> &Option<bool>
True means that the output was originally created in the feed by the AssociateFeed operation. False means it was created using CreateFeed or UpdateFeed. You will need this value if you use the UpdateFeed operation to modify the list of outputs in the feed.