#[non_exhaustive]pub struct TemplateGroupBuilder { /* private fields */ }Expand description
A builder for TemplateGroup.
Implementations
Sourceimpl TemplateGroupBuilder
impl TemplateGroupBuilder
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
A name for the template group.
This field is required.Sourcepub fn template_uris(self, input: impl Into<String>) -> Self
pub fn template_uris(self, input: impl Into<String>) -> Self
Appends an item to template_uris.
To override the contents of this collection use set_template_uris.
An array of Amazon S3 URIs that point to the graphics-compositing templates for this group. You can specify 1 or 2 URIs. Each URI must be in the form s3://bucket-name/key. Elemental Inference reads these templates using the IAM role that you specify in accessRoleArn.
Sourcepub fn set_template_uris(self, input: Option<Vec<String>>) -> Self
pub fn set_template_uris(self, input: Option<Vec<String>>) -> Self
An array of Amazon S3 URIs that point to the graphics-compositing templates for this group. You can specify 1 or 2 URIs. Each URI must be in the form s3://bucket-name/key. Elemental Inference reads these templates using the IAM role that you specify in accessRoleArn.
Sourcepub fn get_template_uris(&self) -> &Option<Vec<String>>
pub fn get_template_uris(&self) -> &Option<Vec<String>>
An array of Amazon S3 URIs that point to the graphics-compositing templates for this group. You can specify 1 or 2 URIs. Each URI must be in the form s3://bucket-name/key. Elemental Inference reads these templates using the IAM role that you specify in accessRoleArn.
Sourcepub fn build(self) -> Result<TemplateGroup, BuildError>
pub fn build(self) -> Result<TemplateGroup, BuildError>
Consumes the builder and constructs a TemplateGroup.
This method will fail if any of the following fields are not set: