#[non_exhaustive]pub struct UpdateOutputBuilder { /* private fields */ }Expand description
A builder for UpdateOutput.
Implementations
Sourceimpl UpdateOutputBuilder
impl UpdateOutputBuilder
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name start here
This field is required.Sourcepub fn output_config(self, input: OutputConfig) -> Self
pub fn output_config(self, input: OutputConfig) -> Self
A typed property for an output in a feed. It is used in the UpdateFeed action. It identifies the action for Elemental Inference to perform. It also provides a repository for the results of that action. For example, CroppingConfig output will contain the metadata for the crop feature.
This field is required.Sourcepub fn set_output_config(self, input: Option<OutputConfig>) -> Self
pub fn set_output_config(self, input: Option<OutputConfig>) -> Self
A typed property for an output in a feed. It is used in the UpdateFeed action. It identifies the action for Elemental Inference to perform. It also provides a repository for the results of that action. For example, CroppingConfig output will contain the metadata for the crop feature.
Sourcepub fn get_output_config(&self) -> &Option<OutputConfig>
pub fn get_output_config(&self) -> &Option<OutputConfig>
A typed property for an output in a feed. It is used in the UpdateFeed action. It identifies the action for Elemental Inference to perform. It also provides a repository for the results of that action. For example, CroppingConfig output will contain the metadata for the crop feature.
Sourcepub fn status(self, input: OutputStatus) -> Self
pub fn status(self, input: OutputStatus) -> Self
The status of the output.
This field is required.Sourcepub fn set_status(self, input: Option<OutputStatus>) -> Self
pub fn set_status(self, input: Option<OutputStatus>) -> Self
The status of the output.
Sourcepub fn get_status(&self) -> &Option<OutputStatus>
pub fn get_status(&self) -> &Option<OutputStatus>
The status of the output.
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
A description of the output.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
A description of the output.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
A description of the output.
Sourcepub fn from_association(self, input: bool) -> Self
pub fn from_association(self, input: bool) -> Self
This property is set by the service when you add the output to the feed, and indicates how you added the output. True means that you used the AssociateFeed operation. False means that you used the CreateFeed or UpdateFeed operation. Use GetFeed to obtain the value. If the value is True, include this field here with a value of True. If the value is False, omit the field here.
Sourcepub fn set_from_association(self, input: Option<bool>) -> Self
pub fn set_from_association(self, input: Option<bool>) -> Self
This property is set by the service when you add the output to the feed, and indicates how you added the output. True means that you used the AssociateFeed operation. False means that you used the CreateFeed or UpdateFeed operation. Use GetFeed to obtain the value. If the value is True, include this field here with a value of True. If the value is False, omit the field here.
Sourcepub fn get_from_association(&self) -> &Option<bool>
pub fn get_from_association(&self) -> &Option<bool>
This property is set by the service when you add the output to the feed, and indicates how you added the output. True means that you used the AssociateFeed operation. False means that you used the CreateFeed or UpdateFeed operation. Use GetFeed to obtain the value. If the value is True, include this field here with a value of True. If the value is False, omit the field here.
Sourcepub fn build(self) -> Result<UpdateOutput, BuildError>
pub fn build(self) -> Result<UpdateOutput, BuildError>
Consumes the builder and constructs a UpdateOutput.
This method will fail if any of the following fields are not set: