#[non_exhaustive]pub struct DataSourceConfiguration {
pub fixture_id: String,
}Expand description
Contains the data source configuration for a clipping output. It identifies the fixture whose event data Elemental Inference maps onto the clipping metadata. It is used in the dataSourceConfiguration property of a ClippingConfig.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.fixture_id: StringThe ID of the fixture whose event data you want Elemental Inference to map onto this clipping output. The fixture should be the sports event in the source media that the feed is processing.
To obtain this ID, use the SearchFixtures operation to find the fixture, then use the fixtureId from the matching FixtureSummary.
Implementations
Sourceimpl DataSourceConfiguration
impl DataSourceConfiguration
Sourcepub fn fixture_id(&self) -> &str
pub fn fixture_id(&self) -> &str
The ID of the fixture whose event data you want Elemental Inference to map onto this clipping output. The fixture should be the sports event in the source media that the feed is processing.
To obtain this ID, use the SearchFixtures operation to find the fixture, then use the fixtureId from the matching FixtureSummary.
Sourceimpl DataSourceConfiguration
impl DataSourceConfiguration
Sourcepub fn builder() -> DataSourceConfigurationBuilder
pub fn builder() -> DataSourceConfigurationBuilder
Creates a new builder-style object to manufacture DataSourceConfiguration.