#[non_exhaustive]pub struct FixtureSummary {
pub fixture_id: String,
pub name: String,
pub fixture_group: Option<String>,
pub scheduled_start: Option<DateTime>,
pub status: String,
pub competitors: Vec<Competitor>,
}Expand description
Contains information about one fixture. It is used in the SearchFixtures response.
Elemental Inference relays the information in this structure from the data source, so that you can identify the fixture that matches your source media.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.fixture_id: StringThe ID of the fixture. Specify this ID in the clipping output of a feed, to identify the fixture whose event data you want Elemental Inference to map onto the clipping metadata.
name: StringThe name of the fixture, as provided by the data source. For example, the names of the two competing teams.
fixture_group: Option<String>The group that the fixture belongs to, such as the competition, league, or tournament. The data source doesn't provide this information for every fixture.
scheduled_start: Option<DateTime>The scheduled start time of the fixture, as provided by the data source. The actual start time might differ.
status: StringThe status of the fixture in its lifecycle, as provided by the data source. For example, Scheduled or Completed.
competitors: Vec<Competitor>An array of the competitors (the teams or individuals) in the fixture.
Implementations
Sourceimpl FixtureSummary
impl FixtureSummary
Sourcepub fn fixture_id(&self) -> &str
pub fn fixture_id(&self) -> &str
The ID of the fixture. Specify this ID in the clipping output of a feed, to identify the fixture whose event data you want Elemental Inference to map onto the clipping metadata.
Sourcepub fn name(&self) -> &str
pub fn name(&self) -> &str
The name of the fixture, as provided by the data source. For example, the names of the two competing teams.
Sourcepub fn fixture_group(&self) -> Option<&str>
pub fn fixture_group(&self) -> Option<&str>
The group that the fixture belongs to, such as the competition, league, or tournament. The data source doesn't provide this information for every fixture.
Sourcepub fn scheduled_start(&self) -> Option<&DateTime>
pub fn scheduled_start(&self) -> Option<&DateTime>
The scheduled start time of the fixture, as provided by the data source. The actual start time might differ.
Sourcepub fn status(&self) -> &str
pub fn status(&self) -> &str
The status of the fixture in its lifecycle, as provided by the data source. For example, Scheduled or Completed.
Sourcepub fn competitors(&self) -> &[Competitor]
pub fn competitors(&self) -> &[Competitor]
An array of the competitors (the teams or individuals) in the fixture.
Sourceimpl FixtureSummary
impl FixtureSummary
Sourcepub fn builder() -> FixtureSummaryBuilder
pub fn builder() -> FixtureSummaryBuilder
Creates a new builder-style object to manufacture FixtureSummary.