#[non_exhaustive]pub struct SubtitlingConfig {
pub language: TranscriptionLanguage,
pub aspect_ratio: Option<AspectRatio>,
pub dictionary: Option<String>,
pub profanity_filter: Option<ProfanityFilterMode>,
}Expand description
A type of OutputConfig, used when the output in a feed is for the smart subtitling feature. smart subtitling uses automatic speech recognition (ASR) to generate live TTML subtitles from the audio in your source media.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.language: TranscriptionLanguageThe language of the audio in the source media. Elemental Inference uses this setting to optimize transcription accuracy. Specify the language using an ISO 639-2/T three-letter code, optionally with a region subtag. Supported values: eng, eng-au, eng-gb, eng-us, fra, ita, deu, spa, por.
aspect_ratio: Option<AspectRatio>The aspect ratio of the output video, specified as width and height integer values. Elemental Inference uses the aspect ratio to determine subtitle layout and line lengths.
dictionary: Option<String>The ID of a custom dictionary to improve transcription accuracy for domain-specific terminology. Use the CreateDictionary operation to create a dictionary.
profanity_filter: Option<ProfanityFilterMode>Controls how profanity is handled in the generated subtitles. Valid values: DISABLED (no filtering, default), CENSOR (replace profanity with asterisks), DROP (remove profanity from the transcript).
Implementations
Sourceimpl SubtitlingConfig
impl SubtitlingConfig
Sourcepub fn language(&self) -> &TranscriptionLanguage
pub fn language(&self) -> &TranscriptionLanguage
The language of the audio in the source media. Elemental Inference uses this setting to optimize transcription accuracy. Specify the language using an ISO 639-2/T three-letter code, optionally with a region subtag. Supported values: eng, eng-au, eng-gb, eng-us, fra, ita, deu, spa, por.
Sourcepub fn aspect_ratio(&self) -> Option<&AspectRatio>
pub fn aspect_ratio(&self) -> Option<&AspectRatio>
The aspect ratio of the output video, specified as width and height integer values. Elemental Inference uses the aspect ratio to determine subtitle layout and line lengths.
Sourcepub fn dictionary(&self) -> Option<&str>
pub fn dictionary(&self) -> Option<&str>
The ID of a custom dictionary to improve transcription accuracy for domain-specific terminology. Use the CreateDictionary operation to create a dictionary.
Sourcepub fn profanity_filter(&self) -> Option<&ProfanityFilterMode>
pub fn profanity_filter(&self) -> Option<&ProfanityFilterMode>
Controls how profanity is handled in the generated subtitles. Valid values: DISABLED (no filtering, default), CENSOR (replace profanity with asterisks), DROP (remove profanity from the transcript).
Sourceimpl SubtitlingConfig
impl SubtitlingConfig
Sourcepub fn builder() -> SubtitlingConfigBuilder
pub fn builder() -> SubtitlingConfigBuilder
Creates a new builder-style object to manufacture SubtitlingConfig.