#[non_exhaustive]pub struct UpdateOutput {
pub name: String,
pub output_config: Option<OutputConfig>,
pub status: OutputStatus,
pub description: Option<String>,
pub from_association: Option<bool>,
}Expand description
Contains configuration information about one output in a feed. It is used in the UpdateFeed action.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe name start here
output_config: Option<OutputConfig>A typed property for an output in a feed. It is used in the UpdateFeed action. It identifies the action for Elemental Inference to perform. It also provides a repository for the results of that action. For example, CroppingConfig output will contain the metadata for the crop feature.
status: OutputStatusThe status of the output.
description: Option<String>A description of the output.
from_association: Option<bool>This property is set by the service when you add the output to the feed, and indicates how you added the output. True means that you used the AssociateFeed operation. False means that you used the CreateFeed or UpdateFeed operation. Use GetFeed to obtain the value. If the value is True, include this field here with a value of True. If the value is False, omit the field here.
Implementations
Sourceimpl UpdateOutput
impl UpdateOutput
Sourcepub fn output_config(&self) -> Option<&OutputConfig>
pub fn output_config(&self) -> Option<&OutputConfig>
A typed property for an output in a feed. It is used in the UpdateFeed action. It identifies the action for Elemental Inference to perform. It also provides a repository for the results of that action. For example, CroppingConfig output will contain the metadata for the crop feature.
Sourcepub fn status(&self) -> &OutputStatus
pub fn status(&self) -> &OutputStatus
The status of the output.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
A description of the output.
Sourcepub fn from_association(&self) -> Option<bool>
pub fn from_association(&self) -> Option<bool>
This property is set by the service when you add the output to the feed, and indicates how you added the output. True means that you used the AssociateFeed operation. False means that you used the CreateFeed or UpdateFeed operation. Use GetFeed to obtain the value. If the value is True, include this field here with a value of True. If the value is False, omit the field here.
Sourceimpl UpdateOutput
impl UpdateOutput
Sourcepub fn builder() -> UpdateOutputBuilder
pub fn builder() -> UpdateOutputBuilder
Creates a new builder-style object to manufacture UpdateOutput.