Supporting types for waiters.
Note: to use waiters, import the Waiters trait, which adds methods prefixed with wait_until to the client.
Modules
- feed_
deleted - Supporting types for the
feed_deletedwaiter.
Supporting types for waiters.
Note: to use waiters, import the Waiters trait, which adds methods prefixed with wait_until to the client.
feed_deleted waiter.