pub struct AssociateFeedFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to AssociateFeed.
Associates a resource with the feed. The resource provides the input that Elemental Inference needs in order to perform an Elemental Inference feature, such as cropping video. You always provide the resource by associating it with a feed. You can associate only one resource with each feed. With an association, a specific source media is claiming ownership of the feed.
AssociateFeed is a PATCH operation, which means that you can include only parameters that you want to change. Parameters that you don't include will not be affected by the operation.
Specifically:
-
You can add more outputs to the existing outputs. New outputs will be appended.
-
You can't modify an existing output (for example to change its name). Instead, use UpdateFeed.
-
You can't delete an existing output. Instead, use UpdateFeed.
Also note that you can't change the feed name with AssociateFeed. Instead, use UpdateFeed.
Implementations
Sourceimpl AssociateFeedFluentBuilder
impl AssociateFeedFluentBuilder
Sourcepub fn as_input(&self) -> &AssociateFeedInputBuilder
pub fn as_input(&self) -> &AssociateFeedInputBuilder
Access the AssociateFeed as a reference.
Sourcepub async fn send(
self,
) -> Result<AssociateFeedOutput, SdkError<AssociateFeedError, HttpResponse>>
pub async fn send( self, ) -> Result<AssociateFeedOutput, SdkError<AssociateFeedError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<AssociateFeedOutput, AssociateFeedError, Self>
pub fn customize( self, ) -> CustomizableOperation<AssociateFeedOutput, AssociateFeedError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn associated_resource_name(self, input: impl Into<String>) -> Self
pub fn associated_resource_name(self, input: impl Into<String>) -> Self
An identifier for the resource. This name must not resemble an ARN.
The resource is the source media that the feed will process. The name you assign should help you to later identify the source media that belongs to the feed. In this way, you will know which source media to push to the feed (using PutMedia).
Sourcepub fn set_associated_resource_name(self, input: Option<String>) -> Self
pub fn set_associated_resource_name(self, input: Option<String>) -> Self
An identifier for the resource. This name must not resemble an ARN.
The resource is the source media that the feed will process. The name you assign should help you to later identify the source media that belongs to the feed. In this way, you will know which source media to push to the feed (using PutMedia).
Sourcepub fn get_associated_resource_name(&self) -> &Option<String>
pub fn get_associated_resource_name(&self) -> &Option<String>
An identifier for the resource. This name must not resemble an ARN.
The resource is the source media that the feed will process. The name you assign should help you to later identify the source media that belongs to the feed. In this way, you will know which source media to push to the feed (using PutMedia).
Sourcepub fn outputs(self, input: CreateOutput) -> Self
pub fn outputs(self, input: CreateOutput) -> Self
Appends an item to outputs.
To override the contents of this collection use set_outputs.
An array of one or more outputs that you want to add to this feed now, to supplement any outputs that you specified when you created or updated the feed.
Sourcepub fn set_outputs(self, input: Option<Vec<CreateOutput>>) -> Self
pub fn set_outputs(self, input: Option<Vec<CreateOutput>>) -> Self
An array of one or more outputs that you want to add to this feed now, to supplement any outputs that you specified when you created or updated the feed.
Sourcepub fn get_outputs(&self) -> &Option<Vec<CreateOutput>>
pub fn get_outputs(&self) -> &Option<Vec<CreateOutput>>
An array of one or more outputs that you want to add to this feed now, to supplement any outputs that you specified when you created or updated the feed.
Sourcepub fn dry_run(self, input: bool) -> Self
pub fn dry_run(self, input: bool) -> Self
Set to true if you want to do a dry run of the associate action.
Elemental Inference will validate that the real request would succeed without actually making any changes. A dry run catches errors such as missing IAM permissions, quota limits exceeded, conflicting outputs, and so on. If the dry run fails, the action returns a 4xx error code. After you've fixed the errors, resubmit the request.
Sourcepub fn set_dry_run(self, input: Option<bool>) -> Self
pub fn set_dry_run(self, input: Option<bool>) -> Self
Set to true if you want to do a dry run of the associate action.
Elemental Inference will validate that the real request would succeed without actually making any changes. A dry run catches errors such as missing IAM permissions, quota limits exceeded, conflicting outputs, and so on. If the dry run fails, the action returns a 4xx error code. After you've fixed the errors, resubmit the request.
Sourcepub fn get_dry_run(&self) -> &Option<bool>
pub fn get_dry_run(&self) -> &Option<bool>
Set to true if you want to do a dry run of the associate action.
Elemental Inference will validate that the real request would succeed without actually making any changes. A dry run catches errors such as missing IAM permissions, quota limits exceeded, conflicting outputs, and so on. If the dry run fails, the action returns a 4xx error code. After you've fixed the errors, resubmit the request.