#[non_exhaustive]pub struct AssociateFeedInput {
pub id: Option<String>,
pub associated_resource_name: Option<String>,
pub outputs: Option<Vec<CreateOutput>>,
pub dry_run: Option<bool>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<String>The ID of the feed.
associated_resource_name: Option<String>An identifier for the resource. This name must not resemble an ARN.
The resource is the source media that the feed will process. The name you assign should help you to later identify the source media that belongs to the feed. In this way, you will know which source media to push to the feed (using PutMedia).
outputs: Option<Vec<CreateOutput>>An array of one or more outputs that you want to add to this feed now, to supplement any outputs that you specified when you created or updated the feed.
dry_run: Option<bool>Set to true if you want to do a dry run of the associate action.
Elemental Inference will validate that the real request would succeed without actually making any changes. A dry run catches errors such as missing IAM permissions, quota limits exceeded, conflicting outputs, and so on. If the dry run fails, the action returns a 4xx error code. After you've fixed the errors, resubmit the request.
Implementations
Sourceimpl AssociateFeedInput
impl AssociateFeedInput
Sourcepub fn associated_resource_name(&self) -> Option<&str>
pub fn associated_resource_name(&self) -> Option<&str>
An identifier for the resource. This name must not resemble an ARN.
The resource is the source media that the feed will process. The name you assign should help you to later identify the source media that belongs to the feed. In this way, you will know which source media to push to the feed (using PutMedia).
Sourcepub fn outputs(&self) -> &[CreateOutput]
pub fn outputs(&self) -> &[CreateOutput]
An array of one or more outputs that you want to add to this feed now, to supplement any outputs that you specified when you created or updated the feed.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .outputs.is_none().
Sourcepub fn dry_run(&self) -> Option<bool>
pub fn dry_run(&self) -> Option<bool>
Set to true if you want to do a dry run of the associate action.
Elemental Inference will validate that the real request would succeed without actually making any changes. A dry run catches errors such as missing IAM permissions, quota limits exceeded, conflicting outputs, and so on. If the dry run fails, the action returns a 4xx error code. After you've fixed the errors, resubmit the request.
Sourceimpl AssociateFeedInput
impl AssociateFeedInput
Sourcepub fn builder() -> AssociateFeedInputBuilder
pub fn builder() -> AssociateFeedInputBuilder
Creates a new builder-style object to manufacture AssociateFeedInput.