pub struct CreateFeedFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to CreateFeed.
Creates a feed. The feed is the target for the live media stream that is being sent by the calling application. An example of a calling application is AWS Elemental MediaLive.
The key contents of the feed is an array of outputs. Each output represents an Elemental Inference feature. After you create the feed, you must associate a resource with the feed. At that point, you will have a useable feed: resource - feed - output or outputs.
Implementations
Sourceimpl CreateFeedFluentBuilder
impl CreateFeedFluentBuilder
Sourcepub fn as_input(&self) -> &CreateFeedInputBuilder
pub fn as_input(&self) -> &CreateFeedInputBuilder
Access the CreateFeed as a reference.
Sourcepub async fn send(
self,
) -> Result<CreateFeedOutput, SdkError<CreateFeedError, HttpResponse>>
pub async fn send( self, ) -> Result<CreateFeedOutput, SdkError<CreateFeedError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<CreateFeedOutput, CreateFeedError, Self>
pub fn customize( self, ) -> CustomizableOperation<CreateFeedOutput, CreateFeedError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn outputs(self, input: CreateOutput) -> Self
pub fn outputs(self, input: CreateOutput) -> Self
Appends an item to outputs.
To override the contents of this collection use set_outputs.
An array of outputs for this feed. Each output represents a specific Elemental Inference feature. For example, there is one output type for the smart crop feature. You must specify at least one output, but you can later add outputs using AssociateFeed, or add, modify, and delete outputs using UpdateFeed.
Sourcepub fn set_outputs(self, input: Option<Vec<CreateOutput>>) -> Self
pub fn set_outputs(self, input: Option<Vec<CreateOutput>>) -> Self
An array of outputs for this feed. Each output represents a specific Elemental Inference feature. For example, there is one output type for the smart crop feature. You must specify at least one output, but you can later add outputs using AssociateFeed, or add, modify, and delete outputs using UpdateFeed.
Sourcepub fn get_outputs(&self) -> &Option<Vec<CreateOutput>>
pub fn get_outputs(&self) -> &Option<Vec<CreateOutput>>
An array of outputs for this feed. Each output represents a specific Elemental Inference feature. For example, there is one output type for the smart crop feature. You must specify at least one output, but you can later add outputs using AssociateFeed, or add, modify, and delete outputs using UpdateFeed.
Adds a key-value pair to tags.
To override the contents of this collection use set_tags.
Optional tags. You can also add tags later, using TagResource.
Optional tags. You can also add tags later, using TagResource.
Optional tags. You can also add tags later, using TagResource.