Module types

Module types 

Data structures used by operation inputs/outputs.

Modules

builders
Builders
error
Error types that AWS Elemental Inference can respond with.

Structs

AspectRatio

The width and height of the output video. Used in SubtitlingConfig to determine subtitle layout.

ClippingConfig

A type of OutputConfig, used when the output in a feed is for the clip feature.

CreateOutput

Contains configuration information about one output in a feed. It is used in the AssociateFeed and the CreateFeed actions.

CroppingConfig

A type of OutputConfig, used when the output in a feed is for the crop feature.

DictionarySummary

Contains summary information about a dictionary. Used in the ListDictionaries response.

FeedAssociation

Contains information about the resource that is associated with a feed. It is used in the FeedSummary that is used in the response of a ListFeeds action.

FeedSummary

Contains configuration information about a feed. It is used in the ListFeeds response.

GetOutput

Contains configuration information about one output in a feed. It is used in the GetFeed response.

SubtitlingConfig

A type of OutputConfig, used when the output in a feed is for the smart subtitling feature. smart subtitling uses automatic speech recognition (ASR) to generate live TTML subtitles from the audio in your source media.

UpdateOutput

Contains configuration information about one output in a feed. It is used in the UpdateFeed action.

Enums

DictionaryLanguage
When writing a match expression against DictionaryLanguage, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature.
DictionaryStatus
When writing a match expression against DictionaryStatus, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature.
FeedStatus
When writing a match expression against FeedStatus, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature.
OutputConfig

Contains one typed output. It is used in the CreateOutput, GetOutput, and Update Output structures.

OutputStatus
When writing a match expression against OutputStatus, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature.
ProfanityFilterMode
When writing a match expression against ProfanityFilterMode, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature.
TranscriptionLanguage
When writing a match expression against TranscriptionLanguage, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature.